pub struct MultiParseResult {
pub results: Vec<ParseResult>,
}Expand description
The result of a lenient multi-song parse.
When using parse_multi_lenient, the parser splits the input at {new_song}
boundaries and parses each segment independently. Each entry in results
contains the lenient parse result for one song segment.
Fields
results: Vec<ParseResult>The parsed songs, one per segment between {new_song} boundaries.
Each entry is the lenient parse result for that song segment.
Implementations
Sourceimpl MultiParseResult
impl MultiParseResult
Sourcepub fn has_errors(&self) -> bool
pub fn has_errors(&self) -> bool
Returns true if any errors were encountered in any song.
Sourcepub fn all_errors(&self) -> Vec<&ParseError>
pub fn all_errors(&self) -> Vec<&ParseError>
Returns all errors from all songs.