pub enum TextSpan {
Plain(String),
Bold(Vec<TextSpan>),
Italic(Vec<TextSpan>),
Highlight(Vec<TextSpan>),
Comment(Vec<TextSpan>),
Span(SpanAttributes, Vec<TextSpan>),
}Expand description
A segment of text that may contain inline markup formatting.
TextSpan represents a tree structure where each node is either plain text
or a formatting tag wrapping child spans. This allows arbitrary nesting of
inline markup.
Variants
Plain(String)
Plain text with no formatting.
Bold(Vec<TextSpan>)
Bold text (<bold> / <b>).
Italic(Vec<TextSpan>)
Italic text (<italic> / <i>).
Highlight(Vec<TextSpan>)
Highlighted text (<highlight>).
Comment(Vec<TextSpan>)
Comment-styled text (<comment>).
Span(SpanAttributes, Vec<TextSpan>)
Styled text with attributes (<span ...>).
Implementations